/****************************************************************/
/* FILENAME: ADS8361_MI.c                            		*/
/* DESCRIPTION: This program uses the TMS470 to read 256 	*/
/*    samples from the ADS78/8361 EVM board in Mode I           */
/*    The samples are stored in data arrays                     */
/*    AUTHOR: T. Hendrick, Data Acquisition Products,           */
/*            Dallas Texas                                      */
/*    CREATED 2006(C) BY TEXAS INSTRUMENTS INCORPORATED.  	*/
/*    VERSION: 01 for SLAA314 - Assumes M0 and M1 jumpers are   */
/*             closed on the ADS8361EVM.                        */
/* Compiled on IAR Assembler for ARM Version 4.30A (4.30.1.537) */
/****************************************************************/
// Note - Channel pair 0 or 1 can be selected by using the A0 jumper on
//  the ADS8361 EVM or via GPIO from the TMS470.

#include <stdio.h>
#include <string.h>
#include <intrinsic.h>
#include "iotms470r1b1m.h"
#include "tms470r1b1m_bit_definitions.h"

// HPA-MCU Interface Board Defines:
#include "HPA_MCU_DEF.h"
/*Declarations*/
#define TABLE_SIZE  128

/*Global variables*/
unsigned int CHA[TABLE_SIZE];
unsigned int CHB[TABLE_SIZE];
int temp1, temp2, temp3, temp4, indx=0, count=0;

void delay(int time)
{
int i;
for (i=0; i<time; i++);
}

void main(void)
{
  // Set up peripheral registers.
  // First disable interrupts.
  __disable_interrupt();
  // Setup system.

  GCR = 0x00000000;
  PCR = 0x00000000;
  PCR = 0x00000001;  // enable peripherals

// char len = 10; SPI SCLK = 9.8MHz
  SPI1CTRL1=0xAA;  // SPI1 controls Serial site 1
  SPI2CTRL1=0xAA;  // SPI2 controls Serial site 2

// SPI1, master mode, CPOL=CPHA=1
  SPI1CTRL2 = 0x28;
// SPI2, slave mode
  SPI2CTRL2 = 0x00;

// SOMI, SIMO and SCLK perform SPI1 functions
  SPI1PC6=0x0E;
// SPISCS, SOMI, SIMO and SCLK perform SPI2 functions
  SPI2PC6=0x0E;

// SPI1SCS is GP output
  SPI1PC1=0x10;

// Enable SPI
 SPI1CTRL2 |= 0x10;
 SPI2CTRL2 |= 0x10;

// Configure ADS8361 Chip Select (I2C2SCL Pin as GPIO)
  I2C2PFNC = 0x01;
  I2C2PDIR = 0x03;

// Loop forever.

  for (;;)
  {
    int i;
    for (i=0; i<TABLE_SIZE; i++)
    {
      I2C2DCLR = 0x03;  // Clear the Chip Select
      SPI1PC3 |= (SCS_DOUT);  // Toggle RD+CONVST high
      // Must write to SPIxDAT1 in order to toggle SPISCS!!!
      SPI1DAT1 = (0x000); // Dummy data to transmitter => start SCLK
       while ((RX_INT_FLAG & SPI1CTRL3) == 0);
       temp1 = SPI1BUF; // Read Data
       temp3 = SPI2BUF; // Read Data
      SPI1PC3 &= ~(SCS_DOUT);  //toggle RD+CONVST low
      SPI1DAT1 = (0x000); // Dummy data to transmitter => start SCLK
       while ((RX_INT_FLAG & SPI1CTRL3) == 0);
       temp2 = SPI1BUF; // Read Data
       temp4 = SPI2BUF; // Read Data
      CHA[i]=((temp1&0x03FF)<<9|(temp2&0x03FF)>>1);
      CHB[i]=((temp3&0x03FF)<<9|(temp4&0x03FF)>>1);
      I2C2DSET = 0x03;  //Set chip select
    }
  }
}
