/****************************************************************/
/* FILENAME: ADS8361_MIV.c                            		*/
/* DESCRIPTION: This program uses the TMS470 to read 256 	*/
/*    samples from the ADS78/8361 EVM board in Mode IV          */
/*    The samples are stored in data arrays                     */
/*    AUTHOR: T. Hendrick, Data Acquisition Products,           */
/*            Dallas Texas                                      */
/*    CREATED 2006(C) BY TEXAS INSTRUMENTS INCORPORATED.  	*/
/*    VERSION: 01 for SLAA314 - Assumes M0 and M1 jumpers are   */
/*             both open on the ADS8361EVM.                     */
/* Compiled on IAR Assembler for ARM Version 4.30A (4.30.1.537) */
/****************************************************************/
// Note - The A0 jumper on the ADS8361 EVM has no effect.

#include <stdio.h>
#include <string.h>
#include <intrinsic.h>
#include "iotms470r1b1m.h"
#include "tms470r1b1m_bit_definitions.h"

// HPA-MCU Interface Board Defines:
#include "HPA_MCU_DEF.h"
/*Declarations*/
#define TABLE_SIZE  128

/*Global variables*/
unsigned int CH0A[TABLE_SIZE];
unsigned int CH1A[TABLE_SIZE];
unsigned int CH0B[TABLE_SIZE];
unsigned int CH1B[TABLE_SIZE];
int temp1, temp2, temp3, indx=0, count=0;

void delay(int time)
{
int i;
for (i=0; i<time; i++);
}

void sort(int data)
{
  int CH = (data & 0x30000);
  switch (CH)
  {
  case 0x00000:
    CH0A[indx] = data & 0xFFFF;
    count+=1;
    break;
  case 0x10000:
    CH0B[indx] = data & 0xFFFF;
    count+=1;
    break;
  case 0x20000:
    CH1A[indx] = data & 0xFFFF;
    count+=1;
    break;
  case 0x30000:
    CH1B[indx] = data & 0xFFFF;
    count+=1;
    break;
  }
  if (count == 4)
  {
    indx+=1;
    if (indx==TABLE_SIZE) indx = 0;
    count = 0;
  }
}


void main(void)
{
  // Set up peripheral registers.
  // First disable interrupts.
  __disable_interrupt();
  // Setup system.

  GCR = 0x00000000;
  PCR = 0x00000000;
  PCR = 0x00000001;  // enable peripherals

// char len = 10; SPI SCLK = 9.8MHz
  SPI1CTRL1=0xAA;  // SPI1 controls Serial site 1
  SPI2CTRL1=0xAA;  // SPI2 controls Serial Site 2

// internal clock, master mode, CPOL=CPHA=0
  SPI1CTRL2 = 0x28;
  SPI2CTRL2 = 0x28;

// SOMI, SIMO and SCLK perform SPI functions
  SPI1PC6=0x0E;
  SPI2PC6=0x0E;

// SPIxSCS is a GP output
  SPI1PC1=0x10;
  SPI1PC1=0x10;

// Enable SPI
 SPI1CTRL2 |= 0x10;
 SPI2CTRL2 |= 0x10;

// Configure ADS8361 Chip Select (I2C2SCL Pin as GPIO)
  I2C2PFNC = 0x01;
  I2C2PDIR = 0x03;

// Loop forever.

 // for (;;)
 // {
    int i;
    for (i=0; i<6; i++)
    {
      I2C2DCLR = 0x03;  // Clear the Chip Select
      SPI1PC3 |= (SCS_DOUT);  // Toggle RD+CONVST high
      // Must write to SPIxDAT1 in order to toggle SPISCS!!!
      SPI1DAT1 = (0x000); // Dummy data to transmitter => start SCLK
       while ((RX_INT_FLAG & SPI1CTRL3) == 0);
       temp1 = SPI1BUF; // Read Data
      SPI1PC3 &= ~(SCS_DOUT);  //toggle RD+CONVST low
      SPI1DAT1 = (0x000); // Dummy data to transmitter => start SCLK
       while ((RX_INT_FLAG & SPI1CTRL3) == 0);
       temp2 = SPI1BUF; // Read Data
      temp3=((temp1&0x03FF)<<9|(temp2&0x03FF)>>1);
      sort(temp3);
      I2C2DSET = 0x03;  //Set chip select
    }
//  }
}
